# region 日志配置
import logging


def log_init(log_level: str):
    """日志初始化

    :param log_level: 日志级别
    :return:
    """

    logging.basicConfig(level=log_level.upper(), format="%(asctime)s %(levelname)s:%(message)s")



from string import Template

_html_root_map = {
    "head": "头",
    "body": "主体",
    "lang": "语言",
    "js": "js"
}

html_root_0 = Template("""<!DOCTYPE HTML>
<html lang="${lang}">
<head>${head}</head>
<body>
<div class="book">${body}</div>
${js}
</body>
</html>
""")

_html_head_map = {
    "title": "标题",
    "author": "作者",
    "base_assets_path": "本页面相对于根的资源相对路径",
    "next_relative_path": "分页：下一页路径，相对于本文件的相对路径",
    "css": "css",
    "description": "页面描述"
}
html_head_1 = Template("""
<meta charset="UTF-8">
<meta content="text/html; charset=utf-8" http-equiv="Content-Type">
<title>${title}</title>
<meta content="IE=edge" http-equiv="X-UA-Compatible"/>
<meta content="" name="description">
<meta content="${author}" name="author">
${css}
<meta content="true" name="HandheldFriendly"/>
<meta content="width=device-width, initial-scale=1, user-scalable=no" name="viewport">
<meta content="yes" name="apple-mobile-web-app-capable">
<meta content="black" name="apple-mobile-web-app-status-bar-style">
<link href="${base_assets_path}/lsbook/images/apple-touch-icon-precomposed-152.png"
      rel="apple-touch-icon-precomposed" sizes="152x152">
<link href="${base_assets_path}/lsbook/images/favicon.ico" rel="shortcut icon" type="image/x-icon">
<!--分页-->
<link href="${next_relative_path}" rel="next"/>
""")

_css_map = {
    "base_assets_path": "本页面相对于根的资源相对路径",
}
css = Template("""
<link href="${base_assets_path}/lsbook/less/website.css" rel="stylesheet">
<link href="${base_assets_path}/lsbook/katex/katex.min.css" rel="stylesheet">
<link href="${base_assets_path}/lsbook/lightbox/css/lightbox.min.css" rel="stylesheet">
""")

_js_map = {
    "base_assets_path": "本页面相对于根的资源相对路径",
}
js = Template("""
<script src="${base_assets_path}/lsbook/jquery-3.3.1.min.js"></script>
<script charset="UTF-8" src="${base_assets_path}/lsbook/jquery_mar/jquery.mark.js"></script>
<script src="${base_assets_path}/lsbook/lightbox/js/lightbox.min.js"></script>
<script src="${base_assets_path}/lsbook/lsbook.min.js"></script>
""")

_html_body_map = {
    "book_summary": "书籍目录",
    "book_body": "书籍主页",
    "basePath": "本页面相对于根的相对路径",
    "language": "语言",
    "LsBook_LINK": "LsBook_LINK",
    "SEARCH_PLACEHOLDER": "SEARCH_PLACEHOLDER",
    "github_url": "github_url",
    "js": "按需加载 js 字典"
}
html_body_2 = Template("""<div class="book-summary">
    <div id="book-search-input" role="search">
        <input placeholder="${SEARCH_PLACEHOLDER}" type="text"/>
    </div>
    <nav role="navigation">
        <ul class="summary">
            ${book_summary}
            <li class="divider"></li>
            <li>
                <a class="lsbook-link" href="https://github.com/liushilive/lsbook" target="blank">
                    ${LsBook_LINK}
                </a>
            </li>
        </ul>
    </nav>
</div>

<div class="book-body">
    ${book_body}
</div>
<script>
    var lsbook = lsbook || [];
    lsbook.push(function () {
        lsbook.page.hasChanged({
            "config": {
                "github_url":"${github_url}",
                "language": "${language}"
            },
            "basePath": "${basePath}",
            "js": ${js}
        });
    });
</script>
""")

_book_summary_map = {
    "data_level": "目录级别",
    "data_path": "文件路径：相对当前文件的相对路径，无需后缀",
    "title": "标题",
    "chapter": "子目录"
}

book_summary_3_head = Template("""<li class="header">${title}</li>""")

book_summary_3_chaptere = Template("""<li class="chapter" data-level="${data_level}" data-path="${data_path}.html">
    <a href="${data_path}.html"><b>${data_level}.</b> ${title}</a>
</li>
""")

book_summary_3_sub_chaptere = Template("""<li class="chapter" data-level="${data_level}" data-path="${data_path}.html">
    <a href="${data_path}.html"><b>${data_level}.</b> ${title}</a>
    <ul class="articles">
    ${chapter}
    </ul>
</li>
""")

book_summary_3_chapter_active = Template("""<li class="chapter active" data-level="${data_level}" data-path="${data_path}.html">
    <a href="${data_path}.html"><b>${data_level}.</b> ${title}</a>
</li>
""")

book_summary_3_sub_chapter_active = Template("""<li class="chapter active" data-level="${data_level}" data-path="${data_path}.html">
    <a href="${data_path}.html"><b>${data_level}.</b> ${title}</a>
    <ul class="articles">
    ${chapter}
    </ul>
</li>
""")

_book_body_map = {
    "previous_page_link": "上一页",
    "next_page_link": "下一页",
    "basePath": "本页面相对于根的相对路径",
    "title": "页面文件名",
    "copyright": "版权声明",
    "toc": "页内目录",
    "footer": "页脚",
    "book_page": "内容",
    "SEARCH_RESULTS_TITLE": "SEARCH_RESULTS_TITLE",
    "SEARCH_NO_RESULTS_TITLE": "SEARCH_NO_RESULTS_TITLE"
}
book_body_4 = Template("""<div class="body-inner">
    <div class="book-header" role="navigation">
        <!-- Title -->
        <h1>
            <i class="fa fa-circle-o-notch fa-spin"></i>
            <a href="${basePath}">${title}</a>
        </h1>
    </div>

    <div class="page-wrapper" role="main" tabindex="-1">
        <div class="page-inner">
            <div class="search-plus" id="book-search-results">
                <div class="search-noresults">
                    <section class="normal markdown-section">
                        ${toc}
                        ${book_page}
                        ${footer}
                    </section>
                </div>
                <div class="search-results">
                    <div class="has-results">
                        <h1 class="search-results-title">${SEARCH_RESULTS_TITLE}</h1>
                        <ul class="search-results-list"></ul>
                    </div>
                    <div class="no-results">
                        <h1 class="search-results-title">${SEARCH_NO_RESULTS_TITLE}</h1>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

${previous_page_link}
${next_page_link}
""")

_previous_page_link_map = {
    "prev_title": "上一页标题",
    "prev_relative_path": "上一页相对路径：相对本页面",
}
previous_page_link_5_1 = Template("""
<a aria-label="Previous page: ${prev_title}" class="navigation navigation-prev" href="${prev_relative_path}">
    <i class="fa fa-angle-left"></i>
</a>
""")

_next_page_link_map = {
    "next_title": "下一页标题",
    "next_relative_path": "下一页相对路径：相对本页面",
}

next_page_link_5_2 = Template("""
<a aria-label="Next page: ${next_title}" class="navigation navigation-next" href="${next_relative_path}">
    <i class="fa fa-angle-right"></i>
</a>
""")



import json
import logging
import os
import re
import time

from ..constants.layouts_html import book_body_4, css, html_body_2, html_head_1, html_root_0, js, next_page_link_5_2, \
    previous_page_link_5_1
from ..models.book import Book
from ..parse.parse_file import parse_file, sectionx
from ..utils.path import get_pure_path, set_extension


def renderer_html(book: Book):
    search_plus_index = {}
    assets_img = set()
    P_list = []
    # config
    author = book.config.get("author", "")
    book_title = book.config.get("title", "")
    language = book.config.get("language", "")
    github_url = book.config.get("github_url", "")

    for item in book.summary_classify_list.values():
        title = item.get("title", "")
        level = item.get("level", "")
        prev_title = item.get("prev_title", "")
        prev_relative_path = item.get("prev_relative_path", "")
        next_title = item.get("next_title", "")
        next_relative_path = item.get("next_relative_path", "")
        book_summary = item.get("summary", "")
        href = item.get("href", "")
        basePath = item.get("basePath", "")

        P_list.append(
            book.pool.submit(_render_html, book_title, title, author, basePath, book_summary,
                             prev_title, prev_relative_path, next_title, next_relative_path,
                             href, book.book_path, book.book_output, language, book.i18n, github_url,
                             book.base_assets, book.book_js
                             )
        )
        logging.debug(f"生成页面：{level, title, href}")

    for ret in P_list:
        dict_, assets_img_ = ret.result()
        search_plus_index.update(dict_)
        assets_img.update(assets_img_)

    # 写入索引
    with open(os.path.join(book.book_output, "search_plus_index.json"), 'w', encoding="utf-8") as f:
        f.write(json.dumps(search_plus_index, ensure_ascii=False))

    return assets_img


def _render_html(book_title, title, author, basePath, book_summary,
                 prev_title, prev_relative_path, next_title, next_relative_path, href, book_path, book_output,
                 language, i18n, github_url, base_assets, book_js):
    """生产HTML，返回索引"""
    # 解析页面
    base_assets_path = os.path.join(basePath, base_assets) if base_assets else basePath  # 资源路径

    book_page, toc_tree, tag_katex, tag_mermaid, tag_prism, tag_lightbox, assets_img = parse_file(
        os.path.join(book_path, href),
        basePath
    )

    # 隐藏答案框
    book_page = sectionx(book_page)
    # 组装页内导航
    toc = ""
    if len(toc_tree) > 0:
        toc = "<div id='anchor-navigation-ex-navbar'><i class='fa fa-anchor'></i><ul><li>" \
              "<span class='title-icon fa fa-hand-o-right'></span><a aria-label class='on-toolbar-action' href='' " \
            f"""onclick="$('.fa.fa-align-justify').parent()[0].click();">{i18n.get('SUMMARY_TOGGLE')}</a></li>"""

        for h1Toc in toc_tree:
            toc += "<li><span class='title-icon fa fa-hand-o-right'></span>" \
                   "<a href='#" + h1Toc["url"] + "'><b>" + h1Toc["level"] + "</b>" + h1Toc["name"] + "</a></li>"
            if len(h1Toc["children"]) > 0:
                toc += "<ul>"
                for h2Toc in h1Toc["children"]:
                    toc += "<li><span class='title-icon fa fa-hand-o-right'></span>" \
                           "<a href='#" + h2Toc["url"] + "'><b>" + h2Toc["level"] + "</b>" + h2Toc["name"] + "</a></li>"
                    if len(h2Toc["children"]) > 0:
                        toc += "<ul>"
                        for h3Toc in h2Toc["children"]:
                            toc += "<li><span class='title-icon fa fa-hand-o-right'></span><a href='#" + h3Toc[
                                "url"] + "'><b>" + h3Toc["level"] + "</b>" + h3Toc["name"] + "</a></li>"
                        toc += "</ul>"
                toc += "</ul>"

        toc += "</ul></div><a href='#" + toc_tree[0]['url'] \
               + "' id='anchorNavigationExGoTop'><i class='fa fa-arrow-up'></i></a>"
    footer = f"""<footer class="page-footer"><span class="copyright">© {time.localtime().tm_year} {author}. 
All rights reserved.</span><span class="footer-modification">
<span id="busuanzi_container_site_uv" style="display:none">本站访客数 <span id="busuanzi_value_site_uv">
</span> 人次</span></span></footer>
<script async src="//busuanzi.ibruce.info/busuanzi/2.3/busuanzi.pure.mini.js"></script>
<script>
{book_js}
</script>"""

    # js
    _js = {}
    if tag_katex:
        _js["katex"] = [f"{base_assets_path}/lsbook/katex/katex.min.js",
                        f"{base_assets_path}/lsbook/katex/contrib/auto-render.min.js"]
    if tag_lightbox:
        pass
    if tag_mermaid:
        _js["mermaid"] = [f"{base_assets_path}/lsbook/mermaid/mermaid.min.js"]
    if tag_prism:
        _js["prism"] = [f"{base_assets_path}/lsbook/prismjs/clipboard.min.js",
                        f"{base_assets_path}/lsbook/prismjs/prism.js"]

    # 上下页
    previous_page_link = prev_relative_path != "" and previous_page_link_5_1.substitute(
        prev_title=prev_title,
        prev_relative_path=prev_relative_path
    ) or ""
    next_page_link = next_relative_path != "" and next_page_link_5_2.substitute(
        next_title=next_title,
        next_relative_path=next_relative_path,
    ) or ""

    # 组装正文
    book_body = book_body_4.substitute(
        previous_page_link=previous_page_link,
        next_page_link=next_page_link,
        title=title,
        basePath=basePath,
        toc=toc,
        footer=footer,
        book_page=book_page,
        SEARCH_RESULTS_TITLE=i18n.get("SEARCH_RESULTS_TITLE"),
        SEARCH_NO_RESULTS_TITLE=i18n.get("SEARCH_NO_RESULTS_TITLE")
    )

    # 组装身体
    body = html_body_2.substitute(
        book_summary=book_summary,
        book_body=book_body,
        basePath=basePath,
        language=language,
        LsBook_LINK=i18n.get("LsBook_LINK"),
        github_url=github_url,
        SEARCH_PLACEHOLDER=i18n.get("SEARCH_PLACEHOLDER"),
        js=_js
    )

    # 组装头
    head = html_head_1.substitute(
        title=f"{book_title} - {title}",
        author=author,
        base_assets_path=base_assets_path,
        next_relative_path=next_relative_path,
        css=css.substitute(base_assets_path=base_assets_path),
        description=title
    )

    # 组装整体
    page = html_root_0.substitute(
        head=head,
        body=body,
        lang=language,
        js=js.substitute(base_assets_path=base_assets_path)
    )

    out_path = os.path.join(book_output, href)

    if os.path.basename(href).lower() == "readme.md":
        out_path = os.path.join(os.path.dirname(out_path), "index.html")
    else:
        out_path = set_extension(out_path, ".html")

    with open(out_path, "w", encoding="utf-8") as f:
        f.write(page)

    body = re.sub(r"(<([^>]+)>)", "", book_page)
    body = re.sub(r"[\n ]+", "", body)

    url = get_pure_path(os.path.relpath(out_path, book_output))

    return {url: {
        "url": url,
        "title": title,
        "keywords": "",
        "body": body,
    }}, assets_img



import mistune

from ..constants.code_extensions import Extensions


class FileRenderer(mistune.Renderer):
    def __init__(self):
        super().__init__()
        self.toc_tree = []
        self.count = {
            "h1": 0,
            "h2": 0,
            "h3": 0
        }
        self._id = 0
        self._img_id = 0
        self.tag_katex = False
        self.tag_mermaid = False
        self.tag_prism = False
        self.tag_lightbox = False

    def header(self, text, level, raw=None):
        """Rendering header/heading tags like ``<h1>`` ``<h2>``.

        :param text: rendered text content for the header.
        :param level: a number for the header level, for example: 1.
        :param raw: raw text content of the header.
        """
        self._id += 1
        _id = f"anchor_{self._id}"
        if level == 1:
            _level = ''
            self.count["h1"] += 1
            self.count["h2"] = 0
            self.count["h3"] = 0
            self.toc_tree.append({
                "name": text,
                "level": _level,
                "url": _id,
                "children": []
            })
        elif level == 2:
            if len(self.toc_tree) > 0:
                self.count['h2'] += 1
                self.count['h3'] = 0
                _level = f"{self.count['h2']}. "
                self.toc_tree[-1]["children"].append({
                    "name": text,
                    "level": _level,
                    "url": _id,
                    "children": []
                })
                text = f"{_level}{text}"
        elif level == 3:
            if len(self.toc_tree) > 0 and len(self.toc_tree[-1]["children"]) > 0:
                self.count['h3'] += 1
                _level = f"{self.count['h2']}.{self.count['h3']}. "
                self.toc_tree[-1]["children"][-1]["children"].append({
                    "name": text,
                    "level": _level,
                    "url": _id,
                    "children": []
                })
                text = f"{_level}{text}"

        return f'<h{level} id="{_id}">' \
            f'<a name="{_id}" class="anchor-navigation-ex-anchor" href="#{_id}">' \
            f'<i class="fa fa-link" aria-hidden="true"></i>' \
            f'</a>' \
            f'{text}' \
            f'</h{level}>'

    def spoiler_in_line(self, body):
        """鼠标扫过显示"""
        body = mistune.escape(body, quote=True, smart_amp=False)
        return f'<span class="spoiler">{body}</span>'

    def katex_in_line(self, body):
        """行内数学公式"""
        self.tag_katex = True
        return f'\({body}\)'

    def katex_in_block(self, body):
        """块内数学公式"""
        self.tag_katex = True
        return f'\[{body}\]'

    def block_code(self, code, lang=None):
        """Rendering block level code. ``pre > code``.

        :param code: text content of the code block.
        :param lang: language of the given code.
        """
        lang = lang and lang.lower()
        # mermaid
        if lang == "mermaid":
            self.tag_mermaid = True
            return f'\n<div class="mermaid">\n{code}\n</div>\n'
        self.tag_prism = True
        # code
        lang = Extensions.get(lang, lang)

        code = code.rstrip('\n')
        code = mistune.escape(code, quote=True, smart_amp=False)
        return f'<pre class="line-numbers"><code class="lang-{lang if lang else "language-markup"}">{code}\n</code></pre>\n'

    def codespan(self, text):
        """Rendering inline `code` text.

        :param text: text content for inline code.
        """
        self.tag_prism = True
        text = mistune.escape(text.rstrip(), smart_amp=False)
        return f' <code class="language-markup">{text}</code> '

    def image(self, src, title, text):
        """Rendering a image with title and text.

        :param src: source link of the image.
        :param title: title text of the image.
        :param text: alt text of the image.
        """
        self.tag_lightbox = True
        src = mistune.escape_link(src)
        text = mistune.escape(text, quote=True)
        self._img_id += 1
        _img_id = self._img_id

        figure = f"""<a data-lightbox="{_img_id}" href="{src}">
  <img alt="{text}" src="{src}" title="{title if title else text}">
</a>"""

        return figure



import logging
import os
import time

from ..models.book import Book
from ..parse.parse_config import is_config_exist
from ..parse.parse_summary import is_summary_exist, parse_summary
from ..renderer.renderer_html import renderer_html
from ..renderer.renderer_summary import renderer_summary
from ..utils.fs import copytree, rmdir, copy, is_file_exist
from ..utils.path import process_input_output_path


def generateBook(book: Book):
    """
    使用生成器生成一本书

    :return:
    """
    start = time.time()
    logging.debug("处理输入输出路径")
    process_input_output_path(book)

    logging.debug("验证书籍目录是否存在")
    is_summary_exist(book)

    logging.debug("验证配置文件并处理")
    is_config_exist(book)

    logging.info("解析目录")
    parse_summary(book)

    # logging.info("验证 readme")
    # readme_exist(book)

    logging.info("生成所有页面的目录结构")
    renderer_summary(book)

    logging.info("复制资源到输出目录")
    rmdir(book.book_output)
    copytree(book.book_path, book.book_output, "_book", "SUMMARY.md", "book.json", ".*")
    if not book.base_assets:
        rmdir(book.assets_path_out)
        copytree(book.assets_path, book.assets_path_out)

    # 读取自定义 js
    if is_file_exist(book.book_path, "book.js"):
        with open(os.path.join(book.book_path, "book.js"), encoding="utf-8") as f:
            book.book_js = f.read()

    logging.info("生成所有页面")
    assets_img = renderer_html(book)

    logging.info("复制外部图片资源到输出目录")
    img_import_path = os.path.join(book.book_output, "lsbook_import_img")
    rmdir(img_import_path)
    while len(assets_img):
        copy(assets_img.pop(), img_import_path)

    logging.info("完成生成")
    end = time.time()
    logging.info(f'共计成功生成 {len(book.summary_classify_list)} 个页面完毕，耗时：{end - start}s !')



Extensions = {
    'csv': 'vim',
    'vi': 'vim',
    'js': 'javascript',
    'py': 'python',
    'rb': 'ruby',
    'ps1': 'powershell',
    'psm1': 'powershell',
    'sh': 'bash',
    'bat': 'batch',
    'h': 'c',
    'tex': 'latex'
}



import json
import logging
import os

from ..models.book import Book
from ..utils.error import file_not_found_error


def is_config_exist(book: Book):
    """验证配置文件是否存在，并读取配置文件内容"""
    book_config = os.path.join(book.book_path, "book.json")
    if not os.path.isfile(book_config):
        file_not_found_error(book_config, "配置文件必不可缺：请确认文件名称：book.json")
    else:
        with open(book_config, encoding="utf-8") as f:
            js = json.load(f)
            book.config = js

    if not os.path.isfile(os.path.join(book.assets_path, f"../i18n/{book.config.get('language', 'zh-cn')}.json")):
        logging.error(f"语言 {book.config.get('language', 'zh-cn')} 错误，使用默认语言：zh-cn")
        book.config['language'] = "zh-cn"

    with open(os.path.join(book.assets_path, f"../i18n/en.json"), encoding="utf-8") as f:
        js = json.load(f)
        book.i18n = js

    with open(os.path.join(book.assets_path, f"../i18n/{book.config.get('language', 'zh-cn')}.json"),
              encoding="utf-8") as f:
        js = json.load(f)
        book.i18n.update(js)



import json
import logging
import os
from concurrent.futures.process import ProcessPoolExecutor
from threading import Thread
from urllib import request

from LsBook.utils.fs import copytree, rmdir
from .models.book import Book
from .output.generateBook import generateBook
from .utils.argument import cmd_argument
from .utils.logger import log_init
from . import __version__

msg = None


def quert_version():
    try:
        global msg
        r = request.urlopen('https://pypi.org/pypi/lsbook/json', timeout=2)
        version = json.loads(r.read().decode('utf-8')).get("info").get("version")
        for x, y in zip(version.split("."), __version__.split(".")):
            if int(x) < int(y):
                break
            elif int(x) == int(y):
                continue
            msg = f"\n当前版本：{__version__}\t已发布最新版本：{version}\n请使用命令\t'pip install -U lsbook'\t升级"
    except:
        pass


def main():
    th = Thread(target=quert_version)
    th.start()

    args = cmd_argument()
    build: bool = args.build
    book_path: str = args.book
    book_output: str = args.output
    log_level: str = args.log
    base_assets = args.base_assets
    assets = args.assets
    log_init(log_level)

    logging.debug(f"入参：{args}")

    try:
        if build:
            logging.info("开始生成书籍")
            pool = ProcessPoolExecutor()
            book = Book(book_path, book_output, pool, base_assets)

            # 生成书籍
            generateBook(book)
        elif assets:
            out = os.path.join(assets, "lsbook")
            logging.info(f"释放资源：{out}")
            rmdir(out)
            copytree(os.path.join(os.path.dirname(__file__), "assets", "lsbook"), out)
            logging.info(f"释放资源完毕")
        else:
            logging.warning("lsbook 查看帮助")
    finally:
        th.join()
        if msg:
            logging.warning(msg)


if __name__ == '__main__':
    main()



from concurrent.futures.process import ProcessPoolExecutor


class Book(object):
    def __init__(self, book_path, book_output, pool: ProcessPoolExecutor, base_assets):
        self._book_path = book_path
        self._book_output = book_output
        self._summary_path = "SUMMARY.md"
        self._summary_json = {}
        self._summary_level_list = []
        self._summary_classify_list = {}
        self._config = {}
        self._assets_path = ["assets", "lsbook"]
        self._assets_path_out = "lsbook"
        self._i18n = {}
        self.pool = pool
        self._base_assets = base_assets
        self._book_js = ""

    @property
    def book_path(self):
        """书籍路径"""
        return self._book_path

    @book_path.setter
    def book_path(self, book_path):
        """设置书籍路径"""
        self._book_path = book_path

    @property
    def book_output(self):
        """书籍输出路径"""
        return self._book_output

    @book_output.setter
    def book_output(self, output):
        """设置书籍输出路径"""
        self._book_output = output

    @property
    def summary_path(self):
        """目录路径"""
        return self._summary_path

    @summary_path.setter
    def summary_path(self, path):
        """目录路径"""
        self._summary_path = path

    @property
    def summary(self):
        """目录结构"""
        return self._summary_json

    @summary.setter
    def summary(self, summary_json):
        """目录结构"""
        self._summary_json = summary_json

    @property
    def config(self):
        """配置"""
        return self._config

    @config.setter
    def config(self, json):
        """配置"""
        self._config = json

    @property
    def assets_path(self):
        """资源路径"""
        return self._assets_path

    @assets_path.setter
    def assets_path(self, path):
        """资源路径"""
        self._assets_path = path

    @property
    def assets_path_out(self):
        """资源输出路径"""
        return self._assets_path_out

    @assets_path_out.setter
    def assets_path_out(self, path):
        """资源输出路径"""
        self._assets_path_out = path

    @property
    def summary_level_list(self):
        """目录层次列表"""
        return self._summary_level_list

    @summary_level_list.setter
    def summary_level_list(self, item):
        """目录层次列表"""
        self._summary_level_list.append(item)

    @property
    def summary_classify_list(self):
        """目录分类后结构"""
        return self._summary_classify_list

    # @summary_classify_list.setter
    # def summary_classify_list(self, item):
    #     """目录分类后结构"""
    #     self._summary_classify_list = item

    @property
    def i18n(self):
        """语言字符"""
        return self._i18n

    @i18n.setter
    def i18n(self, lang):
        """语言字符"""
        self._i18n = lang

    @property
    def book_js(self):
        """自定义 js"""
        return self._book_js

    @book_js.setter
    def book_js(self, book_js):
        """自定义 js"""
        self._book_js = book_js

    @property
    def base_assets(self):
        return self._base_assets
